@@ -84,8 +84,10 @@ void DeclarationBuilder::setPrebuilding(bool prebuilding)
     m_prebuilding = prebuilding;
 }
 
-ReferencedTopDUContext DeclarationBuilder::build(const IndexedString& url, Ast* node, ReferencedTopDUContext updateContext)
+ReferencedTopDUContext DeclarationBuilder::build(const IndexedString& url, Ast* node,
+                                                 const ReferencedTopDUContext& updateContext_)
 {
+    ReferencedTopDUContext updateContext(updateContext_);
     m_correctionHelper.reset(new CorrectionHelper(url, this));
 
     // The declaration builder needs to run twice, so it can resolve uses of e.g. functions
@@ -908,7 +910,7 @@ void DeclarationBuilder::addArgumentTypeHints(CallAst* node, DeclarationPointer
     // - 'parameters' refers to the parameters of the function definition.
     // - 'arguments' refers to the arguments of the function call.
 
-    DUContext* parameterContext = DUChainUtils::getArgumentContext(function);
+    DUContext* parameterContext = DUChainUtils::argumentContext(function);
     FunctionType::Ptr functionType = function->type<FunctionType>();
     if ( ! parameterContext || ! functionType ) {
         return;
@@ -1509,7 +1511,7 @@ void DeclarationBuilder::visitFunctionDefinition( FunctionDefinitionAst* node )
     }
 
     if ( ! dec->isStatic() ) {
-        DUContext* args = DUChainUtils::getArgumentContext(dec);
+        DUContext* args = DUChainUtils::argumentContext(dec);
         if ( args )  {
             QVector<Declaration*> parameters = args->localDeclarations();
             static IndexedString newMethodName("__new__");
